==> dogtag-pki_11.0.0.orig.tar.xz: pki-11.0.0/base/server/src/main/java/com/netscape/cmscore/request/RequestIAttrSetWrapper.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.cmscore.request;

import java.util.Enumeration;

import com.netscape.certsrv.base.EBaseException;
import com.netscape.certsrv.base.IAttrSet;
import com.netscape.certsrv.request.IRequest;

public class RequestIAttrSetWrapper implements IAttrSet {

    IRequest mRequest;

    public RequestIAttrSetWrapper(IRequest request) {
        mRequest = request;
    }

    @Override
    public void set(String name, Object obj) throws EBaseException {
        try {
            mRequest.setExtData(name, (String) obj);
        } catch (ClassCastException e) {
            throw new EBaseException(e.toString());
        }
    }

    @Override
    public Object get(String name) throws EBaseException {
        return mRequest.getExtDataInString(name);
    }

    @Override
    public void delete(String name) throws EBaseException {
        mRequest.deleteExtData(name);
    }

    @Override
    public Enumeration<String> getElements() {
        return mRequest.getExtDataKeys();
    }
}

==> dogtag-pki_11.2.1.orig.tar.xz: pki-11.2.1/base/server/src/main/java/com/netscape/cmscore/request/RequestIAttrSetWrapper.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2007 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.cmscore.request;

import java.util.Enumeration;

import com.netscape.certsrv.base.EBaseException;
import com.netscape.certsrv.base.IAttrSet;

public class RequestIAttrSetWrapper implements IAttrSet {

    Request mRequest;

    public RequestIAttrSetWrapper(Request request) {
        mRequest = request;
    }

    @Override
    public void set(String name, Object obj) throws EBaseException {
        try {
            mRequest.setExtData(name, (String) obj);
        } catch (ClassCastException e) {
            throw new EBaseException(e.toString());
        }
    }

    @Override
    public Object get(String name) throws EBaseException {
        return mRequest.getExtDataInString(name);
    }

    @Override
    public void delete(String name) throws EBaseException {
        mRequest.deleteExtData(name);
    }

    @Override
    public Enumeration<String> getElements() {
        return mRequest.getExtDataKeys();
    }
}
